Version 0.0.1
=============

This version has been released on PyPI. It is available on `GitHub bricoleur <https://github.com/gillespilon/bricoleur>`_.

New features
------------

This is the very first function within the very first module of the bricoleur package. The function 'number_risers' calculates the number of risers (steps) between the upper and lower finish levels of a stair.

Enhancements
------------

TBD

Fixes
-----

TBD

Other
-----

TBD
